#!/usr/bin/env python
# -*- coding: utf-8 -*-

# author: Pocholo
# date: 8/23/22

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.



from gimpfu import *
import os, sys,time
import gettext
gettext.install("gimp20", gimp.locale_directory, unicode=True)

def pm_create_leather_text(customtext, fontname, color1, color2, emboss_deboss):

    #Initiates the temporary state
    pdb.gimp_context_push()
    pdb.gimp_context_set_defaults()
    
    if emboss_deboss==0:
        pdb.gimp_message("No, No, No, Choose the Text Effect first")
    
    if emboss_deboss==1:
        size = 200
        img = pdb.gimp_image_new(1, 1, RGB)
        pdb.gimp_context_set_foreground("#000000")
        textLayer = pdb.gimp_text_fontname(img, None, 0, 0, customtext, 100, 1, size, PIXELS, fontname)
        pdb.gimp_text_layer_set_justification(textLayer, 2)
        pdb.gimp_text_layer_set_line_spacing(textLayer, -10)
        pdb.gimp_text_layer_set_letter_spacing(textLayer, 10)
        #Resize text
        img.resize(textLayer.width, textLayer.height, 0, 0)
        #Rename the text layer and move up
        pdb.gimp_item_set_name(textLayer, "Text")
        textLayer = pdb.gimp_image_get_layer_by_name(img, "Text")
        x = textLayer.offsets[0]
        y = textLayer.offsets[1]
        x = (img.width - textLayer.width) / 2
        y = (img.height - textLayer.height) / 2
        textLayer.set_offsets(x, y)
        pdb.gimp_layer_resize_to_image_size(textLayer)
        pdb.gimp_item_set_visible(textLayer, FALSE)
           
        pdb.gimp_display_new(img)
        
        #Create metal background
        backLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
        pdb.gimp_image_insert_layer(img, backLayer, None, 1)
        pdb.gimp_drawable_fill(backLayer, FILL_WHITE)
        pdb.gimp_item_set_visible(backLayer, FALSE)
        
        size = 256
        #Create the learher texture
        leatherLayer = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "Leather", 100, LAYER_MODE_NORMAL)
        pdb.gimp_image_insert_layer(img, leatherLayer, None, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(leatherLayer, FILL_FOREGROUND)

        #Color #1
        color_1 = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "color #1", 100, LAYER_MODE_SCREEN)
        pdb.gimp_image_insert_layer(img, color_1, None, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(color_1, FILL_FOREGROUND)
        
        #Color #2
        color_2 = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "color #2", 100, LAYER_MODE_MULTIPLY)
        pdb.gimp_image_insert_layer(img, color_2, None, 1)
        pdb.gimp_context_set_background(color2)
        pdb.gimp_drawable_fill(color_2, FILL_FOREGROUND)
           
        #Create a new layer and apply mosaic filter
        mosaicCopy = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "Layer", 100, LAYER_MODE_NORMAL)
        pdb.gimp_image_add_layer(img, mosaicCopy, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(mosaicCopy, FILL_FOREGROUND)
        pdb.plug_in_mosaic(img, mosaicCopy, 
                                    15.0,   #tile_size
                                       2.0,   #tile_height
                                       1.0,   #tile_spacing
                                      0.20,   #tile_neatness
                                         0,   #tile_allow_split
                                       220,   #light_dir
                                         0,   #color_variation
                                         1,   #antialiasing
                                         0,   #color_averaging
                                         1,   #tile_type
                                         0,   #tile_surface
                                         0)   #grout_color

        #Crop image
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        #pdb.gimp_image_select_rectangle(img, 2, 11, 6, 232, 245)
        #pdb.plug_in_autocrop_layer(img, leatherLayer)
        pdb.gimp_selection_none(img)
        #pdb.plug_in_make_seamless(img, leatherLayer)
        
        #Shaping up the leather
        shape = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, shape, None, 1)
        pdb.gimp_layer_set_mode(shape, LAYER_MODE_OVERLAY)
        pdb.gimp_layer_set_opacity(shape, 20)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        
        #Shape up the leather a little more
        layer = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, layer, None, 1)
        pdb.gimp_layer_set_mode(layer, LAYER_MODE_SCREEN)
        pdb.gimp_layer_set_opacity(layer, 100)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        
        #Coloring from original color
        pdb.gimp_brightness_contrast(leatherLayer, 127, 12)
        color = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, color, None, 1)
        pdb.gimp_layer_set_mode(color, LAYER_MODE_MULTIPLY)
        pdb.gimp_layer_set_opacity(color, 92)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(color, FILL_FOREGROUND)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        
        #Reshape
        shape2 = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, shape2, None, 1)
        pdb.gimp_layer_set_opacity(shape2, 35)
        pdb.gimp_layer_set_mode(shape2, LAYER_MODE_SOFTLIGHT)
        pdb.plug_in_neon(img, shape2, 5, 0.50)
        pdb.plug_in_gauss(img, shape2, 45, 45, 1)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_layer_scale(leatherLayer, 128, 128, FALSE)
        
        #Fill Background
        non_empty = pdb.gimp_edit_copy(leatherLayer)
        pdb.gimp_image_remove_layer(img, leatherLayer)
        drawable = pdb.gimp_image_get_layer_by_name(img, "Background")
        pdb.gimp_item_set_visible(drawable, TRUE)
        pdb.gimp_item_set_name(drawable, "Leather")
        pdb.gimp_context_set_pattern("Clipboard Image")
        pdb.gimp_edit_bucket_fill(drawable, BUCKET_FILL_PATTERN, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
        
        #Creating the dark spots on the leather
        spots = pdb.gimp_layer_new_from_drawable(backLayer, img)
        pdb.gimp_image_insert_layer(img, spots, None, 1)
        pdb.gimp_drawable_fill(spots, FILL_WHITE)
        pdb.gimp_layer_set_mode(spots, LAYER_MODE_GRAIN_EXTRACT)
        pdb.gimp_layer_set_opacity(spots, 35)
        pdb.gimp_item_set_name(spots, "Spots")
        pdb.plug_in_solid_noise(img, spots, TRUE, FALSE, 2, 15, 16, 16)
        pdb.plug_in_gauss(img, spots, 150, 150, 1)   #method=1
       
        #Creating the wrinkles on the leather
        wrinklesLayer = pdb.gimp_layer_new_from_drawable(spots, img)
        pdb.gimp_image_insert_layer(img, wrinklesLayer, None, 1)
        pdb.gimp_layer_set_mode(wrinklesLayer, LAYER_MODE_SOFTLIGHT)
        pdb.gimp_layer_set_opacity(wrinklesLayer, 50)
        pdb.plug_in_gmic_qt(img, wrinklesLayer, 1, 0, "-fx_cracks 14,1,255,255,255,128,0,0,50,50")
        pdb.plug_in_gmic_qt(img, wrinklesLayer, 1, 0, "-fx_breaks 0,42,27,0.3,3")
        pdb.plug_in_gauss(img, wrinklesLayer, 3, 3, 1)   #method=1
        backLayer = pdb.gimp_image_merge_visible_layers(img, EXPAND_AS_NECESSARY)   
        
        #Text inner glow
        color = "#332400"
        opacity = 100.0
        contour = 0        #Rounded step
        noise = 0.0
        mode = 5             #LAYER_MODE_OVERLAY_LEGACY
        source = 1
        choke = 0.0
        size = 14
        merge = FALSE
        pdb.python_layerfx_inner_glow(img, textLayer, color, opacity, contour, noise, mode, source, choke, size, merge)
        
        #Text outer glow
        color = "#823e11"
        opacity = 70.0
        contour = 0        #Rounded step
        noise = 0.0
        mode = 17            #LAYER_MODE_BURN_LEGACY
        spread = 7
        size = 15
        knockout = TRUE
        merge = FALSE
        pdb.python_layerfx_outer_glow(img, textLayer, color, opacity, contour, noise, mode, spread, size, knockout, merge)
        
        #Text bevel and emboss
        style = 1                      #Inner bevel
        depth = 65
        direction = 0                  #Up
        size = 30
        soften = 0
        angle = 120.0
        altitude = 30.0
        glosscontour = 10                #Rounded Steps
        highlightcolor = ("#7c674f")
        highlightmode = 5               #LAYER_MODE_OVERLAY_LEGACY
        highlightopacity = 75.0
        shadowcolor = ("#3b2c1a")
        shadowmode = 5                  #LAYER_MODE_OVERLAY_LEGACY
        shadowopacity = 75.0
        surfacecontour = 8              #Ring Double
        use_texture = FALSE
        pattern = _("Clipboard Image")
        scale = 100.0
        tex_depth = -34.0
        invert = FALSE
        merge = FALSE
        pdb.python_layerfx_bevel_emboss(img, textLayer, 
                                        style, depth, direction, size, soften, angle, altitude, glosscontour, highlightcolor, highlightmode, 
                                        highlightopacity, shadowcolor, shadowmode, 
                                        shadowopacity, surfacecontour, use_texture, pattern, scale, tex_depth, invert, merge)
        
        #Text pattern overlay
        pattern = _("Clipboard Image")
        opacity = 100.0
        mode = 0                        #LAYER_MODE_NORMAL_LEGACY
        scale = 100
        interpolation_type = 0          #INTERPOLATION_NONE
        merge = FALSE
        pdb.python_layerfx_pattern_overlay(img, textLayer, pattern, opacity, mode, scale, interpolation_type, merge)
        
        #Text copy
        textCopy = pdb.gimp_layer_new_from_drawable(textLayer, img)
        pdb.gimp_image_insert_layer(img, textCopy, None, 0)
        pdb.gimp_layer_set_mode(textCopy, LAYER_MODE_NORMAL_LEGACY)
        pdb.gimp_layer_set_opacity(textCopy, 0)
        
        #Text bevel and emboss
        style = 1                      #Inner bevel
        depth = 65
        direction = 0                  #Up
        size = 30
        soften = 0
        angle = 120.0
        altitude = 20.0
        glosscontour = 10                #Rounded Steps
        highlightcolor = ("#7c674f")
        highlightmode = 5               #LAYER_MODE_OVERLAY_LEGACY
        highlightopacity = 75.0
        shadowcolor = ("#3b2c1a")
        shadowmode = 5                  #LAYER_MODE_OVERLAY_LEGACY
        shadowopacity = 0.0
        surfacecontour = 8              #Ring Double
        use_texture = TRUE
        pattern = _("Clipboard Image")
        scale = 100.0
        tex_depth = -34.0
        invert = TRUE
        merge = FALSE
        pdb.python_layerfx_bevel_emboss(img, textCopy, 
                                        style, depth, direction, size, soften, angle, altitude, glosscontour, highlightcolor, highlightmode, 
                                        highlightopacity, shadowcolor, shadowmode, 
                                        shadowopacity, surfacecontour, use_texture, pattern, scale, tex_depth, invert, merge)
    
    
    if emboss_deboss==2:  
        size = 200
        img = pdb.gimp_image_new(1, 1, RGB)
        pdb.gimp_context_set_foreground("#000000")
        textLayer = pdb.gimp_text_fontname(img, None, 0, 0, customtext, 100, 1, size, PIXELS, fontname)
        pdb.gimp_text_layer_set_justification(textLayer, 2)
        pdb.gimp_text_layer_set_line_spacing(textLayer, -10)
        pdb.gimp_text_layer_set_letter_spacing(textLayer, 10)
        #Resize text
        img.resize(textLayer.width, textLayer.height, 0, 0)
        #Rename the text layer and move up
        pdb.gimp_item_set_name(textLayer, "Text")
        textLayer = pdb.gimp_image_get_layer_by_name(img, "Text")
        x = textLayer.offsets[0]
        y = textLayer.offsets[1]
        x = (img.width - textLayer.width) / 2
        y = (img.height - textLayer.height) / 2
        textLayer.set_offsets(x, y)
        pdb.gimp_layer_resize_to_image_size(textLayer)
        pdb.gimp_item_set_visible(textLayer, FALSE)
           
        pdb.gimp_display_new(img)
        
        #Create metal background
        backLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
        pdb.gimp_image_insert_layer(img, backLayer, None, 1)
        pdb.gimp_drawable_fill(backLayer, FILL_WHITE)
        pdb.gimp_item_set_visible(backLayer, FALSE)
        
        size = 256
        #Create the learher texture
        leatherLayer = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "Leather", 100, LAYER_MODE_NORMAL)
        pdb.gimp_image_insert_layer(img, leatherLayer, None, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(leatherLayer, FILL_FOREGROUND)

        #Color #1
        color_1 = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "color #1", 100, LAYER_MODE_SCREEN)
        pdb.gimp_image_insert_layer(img, color_1, None, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(color_1, FILL_FOREGROUND)
        
        #Color #2
        color_2 = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "color #2", 100, LAYER_MODE_MULTIPLY)
        pdb.gimp_image_insert_layer(img, color_2, None, 1)
        pdb.gimp_context_set_background(color2)
        pdb.gimp_drawable_fill(color_2, FILL_FOREGROUND)
           
        #Create a new layer and apply mosaic filter
        mosaicCopy = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "Layer", 100, LAYER_MODE_NORMAL)
        pdb.gimp_image_add_layer(img, mosaicCopy, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(mosaicCopy, FILL_FOREGROUND)
        pdb.plug_in_mosaic(img, mosaicCopy, 
                                    15.0,   #tile_size
                                       2.0,   #tile_height
                                       1.0,   #tile_spacing
                                      0.20,   #tile_neatness
                                         0,   #tile_allow_split
                                       220,   #light_dir
                                         0,   #color_variation
                                         1,   #antialiasing
                                         0,   #color_averaging
                                         1,   #tile_type
                                         0,   #tile_surface
                                         0)   #grout_color

        #Crop image
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        #pdb.gimp_image_select_rectangle(img, 2, 11, 6, 232, 245)
        #pdb.plug_in_autocrop_layer(img, leatherLayer)
        pdb.gimp_selection_none(img)
        #pdb.plug_in_make_seamless(img, leatherLayer)
        
        #Shaping up the leather
        shape = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, shape, None, 1)
        pdb.gimp_layer_set_mode(shape, LAYER_MODE_OVERLAY)
        pdb.gimp_layer_set_opacity(shape, 20)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        
        #Shape up the leather a little more
        layer = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, layer, None, 1)
        pdb.gimp_layer_set_mode(layer, LAYER_MODE_SCREEN)
        pdb.gimp_layer_set_opacity(layer, 100)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        
        #Coloring from original color
        pdb.gimp_brightness_contrast(leatherLayer, 127, 12)
        color = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, color, None, 1)
        pdb.gimp_layer_set_mode(color, LAYER_MODE_MULTIPLY)
        pdb.gimp_layer_set_opacity(color, 92)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(color, FILL_FOREGROUND)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        
        #Reshape
        shape2 = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, shape2, None, 1)
        pdb.gimp_layer_set_opacity(shape2, 35)
        pdb.gimp_layer_set_mode(shape2, LAYER_MODE_SOFTLIGHT)
        pdb.plug_in_neon(img, shape2, 5, 0.50)
        pdb.plug_in_gauss(img, shape2, 45, 45, 1)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_layer_scale(leatherLayer, 128, 128, FALSE)
        
        #Fill Background
        non_empty = pdb.gimp_edit_copy(leatherLayer)
        pdb.gimp_image_remove_layer(img, leatherLayer)
        drawable = pdb.gimp_image_get_layer_by_name(img, "Background")
        pdb.gimp_item_set_visible(drawable, TRUE)
        pdb.gimp_item_set_name(drawable, "Leather")
        pdb.gimp_context_set_pattern("Clipboard Image")
        pdb.gimp_edit_bucket_fill(drawable, BUCKET_FILL_PATTERN, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
        
        #Creating the dark spots on the leather
        spots = pdb.gimp_layer_new_from_drawable(backLayer, img)
        pdb.gimp_image_insert_layer(img, spots, None, 1)
        pdb.gimp_drawable_fill(spots, FILL_WHITE)
        pdb.gimp_layer_set_mode(spots, LAYER_MODE_GRAIN_EXTRACT)
        pdb.gimp_layer_set_opacity(spots, 35)
        pdb.gimp_item_set_name(spots, "Spots")
        pdb.plug_in_solid_noise(img, spots, TRUE, FALSE, 2, 15, 16, 16)
        pdb.plug_in_gauss(img, spots, 150, 150, 1)   #method=1
       
        #Creating the wrinkles on the leather
        wrinklesLayer = pdb.gimp_layer_new_from_drawable(spots, img)
        pdb.gimp_image_insert_layer(img, wrinklesLayer, None, 1)
        pdb.gimp_layer_set_mode(wrinklesLayer, LAYER_MODE_SOFTLIGHT)
        pdb.gimp_layer_set_opacity(wrinklesLayer, 50)
        pdb.plug_in_gmic_qt(img, wrinklesLayer, 1, 0, "-fx_cracks 14,1,255,255,255,128,0,0,50,50")
        pdb.plug_in_gmic_qt(img, wrinklesLayer, 1, 0, "-fx_breaks 0,42,27,0.3,3")
        pdb.plug_in_gauss(img, wrinklesLayer, 3, 3, 1)   #method=1
        backLayer = pdb.gimp_image_merge_visible_layers(img, EXPAND_AS_NECESSARY)   
        
        pdb.gimp_item_set_visible(textLayer, TRUE)
        pdb.gimp_layer_set_opacity(textLayer, 60)
        pdb.gimp_image_select_item(img, 2, textLayer)
        pdb.gimp_selection_feather(img, 3)
        pdb.gimp_selection_invert(img)
        pdb.script_fu_drop_shadow(img, textLayer, 3, 3, 1, "#000000", 100, FALSE)
        pdb.gimp_selection_invert(img)
        pdb.script_fu_drop_shadow(img, textLayer, 3, 3, 1, "#ffffff", 100, FALSE)
        dropshaLayer = pdb.gimp_image_get_layer_by_name(img, "Drop Shadow #1")
        pdb.gimp_layer_set_mode(dropshaLayer, LAYER_MODE_SOFTLIGHT_LEGACY)
        pdb.gimp_layer_set_opacity(dropshaLayer, 50)
        pdb.gimp_selection_none(img)
        
        
def pm_create_leather_text_atl(img, layer, color1, color2, emboss_deboss):

    #Initiates the temporary state
    pdb.gimp_context_push()
    pdb.gimp_context_set_defaults()
    
    #Make the background active
    img.layers[-1]
    backLayer = img.layers[-1]
    pdb.gimp_image_set_active_layer(img, backLayer)
    pdb.gimp_item_set_name(backLayer, "Background")
    pdb.gimp_context_set_background("#ffffff")
    pdb.gimp_drawable_fill(backLayer, FILL_BACKGROUND)
    
    #Make the text active
    img.layers[0]
    textLayer = img.layers[0]
    textLayer = pdb.gimp_image_set_active_layer(img, textLayer)      
    if textLayer==False:
        pdb.gimp_message_set_handler(0)
        pdb.gimp_message("Need to create a Text")       
        gimp.quit()
    
    if emboss_deboss==0:
        pdb.gimp_message("No, No, No, Choose the Text Effect first")
    
    if emboss_deboss==1:
        #Center the text and change attribute 
        textLayer = pdb.gimp_image_get_active_drawable(img)
        pdb.gimp_image_set_active_layer(img, textLayer)
        pdb.gimp_item_set_name(textLayer, "Text")
        text_layer = pdb.gimp_item_is_text_layer(textLayer)
        line_spacing = pdb.gimp_text_layer_get_line_spacing(textLayer)
        pdb.gimp_text_layer_set_line_spacing(textLayer, -10)
        pdb.gimp_text_layer_set_letter_spacing(textLayer, 10)
        
        #Center the text
        wh = pdb.gimp_drawable_width(textLayer)
        hh = pdb.gimp_drawable_height(textLayer)
        w = pdb.gimp_image_width(img)
        h = pdb.gimp_image_height(img)    
        factor = min (float(img.width) / textLayer.width, float(img.height) / textLayer.height)
        textLayer.scale(int(textLayer.width * factor-150), int(textLayer.height * factor-50))
        x = textLayer.offsets[0]
        y = textLayer.offsets[1]
        x = (img.width - textLayer.width) / 2
        y = (img.height - textLayer.height) / 2
        textLayer.set_offsets(x, y)
        pdb.gimp_layer_resize_to_image_size(textLayer)
        pdb.gimp_image_select_item(img, 2, textLayer)
        pdb.plug_in_antialias(img, textLayer)
        pdb.gimp_context_set_foreground("#000000")
        pdb.gimp_bucket_fill(textLayer, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255,  FALSE, 0, 0)
        pdb.gimp_selection_none(img)
        pdb.gimp_item_set_visible(textLayer, FALSE)
        pdb.gimp_item_set_visible(backLayer, FALSE)
                
        #Create the learher texture
        size = 256
        leatherLayer = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "Leather", 100, LAYER_MODE_NORMAL)
        pdb.gimp_image_insert_layer(img, leatherLayer, None, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(leatherLayer, FILL_FOREGROUND)

        #Color #1
        color_1 = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "color #1", 100, LAYER_MODE_SCREEN)
        pdb.gimp_image_insert_layer(img, color_1, None, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(color_1, FILL_FOREGROUND)
        
        #Color #2
        color_2 = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "color #2", 100, LAYER_MODE_MULTIPLY)
        pdb.gimp_image_insert_layer(img, color_2, None, 1)
        pdb.gimp_context_set_background(color2)
        pdb.gimp_drawable_fill(color_2, FILL_FOREGROUND)
           
        #Create a new layer and apply mosaic filter
        mosaicCopy = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "Layer", 100, LAYER_MODE_NORMAL)
        pdb.gimp_image_add_layer(img, mosaicCopy, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(mosaicCopy, FILL_FOREGROUND)
        pdb.plug_in_mosaic(img, mosaicCopy, 
                                    15.0,   #tile_size
                                       2.0,   #tile_height
                                       1.0,   #tile_spacing
                                      0.20,   #tile_neatness
                                         0,   #tile_allow_split
                                       220,   #light_dir
                                         0,   #color_variation
                                         1,   #antialiasing
                                         0,   #color_averaging
                                         1,   #tile_type
                                         0,   #tile_surface
                                         0)   #grout_color

        #Crop image
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        #pdb.gimp_image_select_rectangle(img, 2, 11, 6, 232, 245)
        #pdb.plug_in_autocrop_layer(img, leatherLayer)
        pdb.gimp_selection_none(img)
        #pdb.plug_in_make_seamless(img, leatherLayer)
        
        #Shaping up the leather
        shape = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, shape, None, 1)
        pdb.gimp_layer_set_mode(shape, LAYER_MODE_OVERLAY)
        pdb.gimp_layer_set_opacity(shape, 20)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        
        #Shape up the leather a little more
        layer = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, layer, None, 1)
        pdb.gimp_layer_set_mode(layer, LAYER_MODE_SCREEN)
        pdb.gimp_layer_set_opacity(layer, 100)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        
        #Coloring from original color
        pdb.gimp_brightness_contrast(leatherLayer, 127, 12)
        color = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, color, None, 1)
        pdb.gimp_layer_set_mode(color, LAYER_MODE_MULTIPLY)
        pdb.gimp_layer_set_opacity(color, 92)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(color, FILL_FOREGROUND)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        
        #Reshape
        shape2 = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, shape2, None, 1)
        pdb.gimp_layer_set_opacity(shape2, 35)
        pdb.gimp_layer_set_mode(shape2, LAYER_MODE_SOFTLIGHT)
        pdb.plug_in_neon(img, shape2, 5, 0.50)
        pdb.plug_in_gauss(img, shape2, 45, 45, 1)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_layer_scale(leatherLayer, 128, 128, FALSE)
        
        #Fill Background
        non_empty = pdb.gimp_edit_copy(leatherLayer)
        pdb.gimp_image_remove_layer(img, leatherLayer)
        drawable = pdb.gimp_image_get_layer_by_name(img, "Background")
        pdb.gimp_item_set_visible(drawable, TRUE)
        pdb.gimp_item_set_name(drawable, "Leather")
        pdb.gimp_context_set_pattern("Clipboard Image")
        pdb.gimp_edit_bucket_fill(drawable, BUCKET_FILL_PATTERN, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
        
        #Creating the dark spots on the leather
        spots = pdb.gimp_layer_new_from_drawable(backLayer, img)
        pdb.gimp_image_insert_layer(img, spots, None, 1)
        pdb.gimp_drawable_fill(spots, FILL_WHITE)
        pdb.gimp_layer_set_mode(spots, LAYER_MODE_GRAIN_EXTRACT)
        pdb.gimp_layer_set_opacity(spots, 35)
        pdb.gimp_item_set_name(spots, "Spots")
        pdb.plug_in_solid_noise(img, spots, TRUE, FALSE, 2, 15, 16, 16)
        pdb.plug_in_gauss(img, spots, 150, 150, 1)   #method=1
       
        #Creating the wrinkles on the leather
        wrinklesLayer = pdb.gimp_layer_new_from_drawable(spots, img)
        pdb.gimp_image_insert_layer(img, wrinklesLayer, None, 1)
        pdb.gimp_layer_set_mode(wrinklesLayer, LAYER_MODE_SOFTLIGHT)
        pdb.gimp_layer_set_opacity(wrinklesLayer, 50)
        pdb.plug_in_gmic_qt(img, wrinklesLayer, 1, 0, "-fx_cracks 14,1,255,255,255,128,0,0,50,50")
        pdb.plug_in_gmic_qt(img, wrinklesLayer, 1, 0, "-fx_breaks 0,42,27,0.3,3")
        pdb.plug_in_gauss(img, wrinklesLayer, 3, 3, 1)   #method=1
        backLayer = pdb.gimp_image_merge_visible_layers(img, EXPAND_AS_NECESSARY)   
        
        #Text inner glow
        color = "#332400"
        opacity = 100.0
        contour = 0        #Rounded step
        noise = 0.0
        mode = 5             #LAYER_MODE_OVERLAY_LEGACY
        source = 1
        choke = 0.0
        size = 14
        merge = FALSE
        pdb.python_layerfx_inner_glow(img, textLayer, color, opacity, contour, noise, mode, source, choke, size, merge)
        
        #Text outer glow
        color = "#823e11"
        opacity = 70.0
        contour = 0        #Rounded step
        noise = 0.0
        mode = 17            #LAYER_MODE_BURN_LEGACY
        spread = 7
        size = 15
        knockout = TRUE
        merge = FALSE
        pdb.python_layerfx_outer_glow(img, textLayer, color, opacity, contour, noise, mode, spread, size, knockout, merge)
        
        #Text bevel and emboss
        style = 1                      #Inner bevel
        depth = 65
        direction = 0                  #Up
        size = 30
        soften = 0
        angle = 120.0
        altitude = 30.0
        glosscontour = 10                #Rounded Steps
        highlightcolor = ("#7c674f")
        highlightmode = 5               #LAYER_MODE_OVERLAY_LEGACY
        highlightopacity = 75.0
        shadowcolor = ("#3b2c1a")
        shadowmode = 5                  #LAYER_MODE_OVERLAY_LEGACY
        shadowopacity = 75.0
        surfacecontour = 8              #Ring Double
        use_texture = FALSE
        pattern = _("Clipboard Image")
        scale = 100.0
        tex_depth = -34.0
        invert = FALSE
        merge = FALSE
        pdb.python_layerfx_bevel_emboss(img, textLayer, 
                                        style, depth, direction, size, soften, angle, altitude, glosscontour, highlightcolor, highlightmode, 
                                        highlightopacity, shadowcolor, shadowmode, 
                                        shadowopacity, surfacecontour, use_texture, pattern, scale, tex_depth, invert, merge)
        
        #Text pattern overlay
        pattern = _("Clipboard Image")
        opacity = 100.0
        mode = 0                        #LAYER_MODE_NORMAL_LEGACY
        scale = 100
        interpolation_type = 0          #INTERPOLATION_NONE
        merge = FALSE
        pdb.python_layerfx_pattern_overlay(img, textLayer, pattern, opacity, mode, scale, interpolation_type, merge)
        
        #Text copy
        textCopy = pdb.gimp_layer_new_from_drawable(textLayer, img)
        pdb.gimp_image_insert_layer(img, textCopy, None, 0)
        pdb.gimp_layer_set_mode(textCopy, LAYER_MODE_NORMAL_LEGACY)
        pdb.gimp_layer_set_opacity(textCopy, 0)
        
        #Text bevel and emboss
        style = 1                      #Inner bevel
        depth = 65
        direction = 0                  #Up
        size = 30
        soften = 0
        angle = 120.0
        altitude = 20.0
        glosscontour = 10                #Rounded Steps
        highlightcolor = ("#7c674f")
        highlightmode = 5               #LAYER_MODE_OVERLAY_LEGACY
        highlightopacity = 75.0
        shadowcolor = ("#3b2c1a")
        shadowmode = 5                  #LAYER_MODE_OVERLAY_LEGACY
        shadowopacity = 0.0
        surfacecontour = 8              #Ring Double
        use_texture = TRUE
        pattern = _("Clipboard Image")
        scale = 100.0
        tex_depth = -34.0
        invert = TRUE
        merge = FALSE
        pdb.python_layerfx_bevel_emboss(img, textCopy, 
                                        style, depth, direction, size, soften, angle, altitude, glosscontour, highlightcolor, highlightmode, 
                                        highlightopacity, shadowcolor, shadowmode, 
                                        shadowopacity, surfacecontour, use_texture, pattern, scale, tex_depth, invert, merge)
    
    
    if emboss_deboss==2:  
        #Center the text and change attribute 
        textLayer = pdb.gimp_image_get_active_drawable(img)
        pdb.gimp_image_set_active_layer(img, textLayer)
        pdb.gimp_item_set_name(textLayer, "Text")
        text_layer = pdb.gimp_item_is_text_layer(textLayer)
        line_spacing = pdb.gimp_text_layer_get_line_spacing(textLayer)
        pdb.gimp_text_layer_set_line_spacing(textLayer, -10)
        pdb.gimp_text_layer_set_letter_spacing(textLayer, 10)
        
        #Center the text
        wh = pdb.gimp_drawable_width(textLayer)
        hh = pdb.gimp_drawable_height(textLayer)
        w = pdb.gimp_image_width(img)
        h = pdb.gimp_image_height(img)    
        factor = min (float(img.width) / textLayer.width, float(img.height) / textLayer.height)
        textLayer.scale(int(textLayer.width * factor-150), int(textLayer.height * factor-50))
        x = textLayer.offsets[0]
        y = textLayer.offsets[1]
        x = (img.width - textLayer.width) / 2
        y = (img.height - textLayer.height) / 2
        textLayer.set_offsets(x, y)
        pdb.gimp_layer_resize_to_image_size(textLayer)
        pdb.gimp_image_select_item(img, 2, textLayer)
        pdb.plug_in_antialias(img, textLayer)
        pdb.gimp_context_set_foreground("#000000")
        pdb.gimp_bucket_fill(textLayer, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255,  FALSE, 0, 0)
        pdb.gimp_selection_none(img)
        pdb.gimp_item_set_visible(textLayer, FALSE)
        pdb.gimp_item_set_visible(backLayer, FALSE)
        
        size = 256
        #Create the learher texture
        leatherLayer = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "Leather", 100, LAYER_MODE_NORMAL)
        pdb.gimp_image_insert_layer(img, leatherLayer, None, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(leatherLayer, FILL_FOREGROUND)

        #Color #1
        color_1 = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "color #1", 100, LAYER_MODE_SCREEN)
        pdb.gimp_image_insert_layer(img, color_1, None, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(color_1, FILL_FOREGROUND)
        
        #Color #2
        color_2 = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "color #2", 100, LAYER_MODE_MULTIPLY)
        pdb.gimp_image_insert_layer(img, color_2, None, 1)
        pdb.gimp_context_set_background(color2)
        pdb.gimp_drawable_fill(color_2, FILL_FOREGROUND)
           
        #Create a new layer and apply mosaic filter
        mosaicCopy = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "Layer", 100, LAYER_MODE_NORMAL)
        pdb.gimp_image_add_layer(img, mosaicCopy, 1)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(mosaicCopy, FILL_FOREGROUND)
        pdb.plug_in_mosaic(img, mosaicCopy, 
                                    15.0,   #tile_size
                                       2.0,   #tile_height
                                       1.0,   #tile_spacing
                                      0.20,   #tile_neatness
                                         0,   #tile_allow_split
                                       220,   #light_dir
                                         0,   #color_variation
                                         1,   #antialiasing
                                         0,   #color_averaging
                                         1,   #tile_type
                                         0,   #tile_surface
                                         0)   #grout_color

        #Crop image
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        #pdb.gimp_image_select_rectangle(img, 2, 11, 6, 232, 245)
        #pdb.plug_in_autocrop_layer(img, leatherLayer)
        pdb.gimp_selection_none(img)
        #pdb.plug_in_make_seamless(img, leatherLayer)
        
        #Shaping up the leather
        shape = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, shape, None, 1)
        pdb.gimp_layer_set_mode(shape, LAYER_MODE_OVERLAY)
        pdb.gimp_layer_set_opacity(shape, 20)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        
        #Shape up the leather a little more
        layer = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, layer, None, 1)
        pdb.gimp_layer_set_mode(layer, LAYER_MODE_SCREEN)
        pdb.gimp_layer_set_opacity(layer, 100)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_item_set_name(leatherLayer, "Leather")
        
        #Coloring from original color
        pdb.gimp_brightness_contrast(leatherLayer, 127, 12)
        color = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, color, None, 1)
        pdb.gimp_layer_set_mode(color, LAYER_MODE_MULTIPLY)
        pdb.gimp_layer_set_opacity(color, 92)
        pdb.gimp_context_set_foreground(color1)
        pdb.gimp_drawable_fill(color, FILL_FOREGROUND)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        
        #Reshape
        shape2 = pdb.gimp_layer_new_from_drawable(leatherLayer, img)
        pdb.gimp_image_insert_layer(img, shape2, None, 1)
        pdb.gimp_layer_set_opacity(shape2, 35)
        pdb.gimp_layer_set_mode(shape2, LAYER_MODE_SOFTLIGHT)
        pdb.plug_in_neon(img, shape2, 5, 0.50)
        pdb.plug_in_gauss(img, shape2, 45, 45, 1)
        leatherLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
        pdb.gimp_layer_scale(leatherLayer, 128, 128, FALSE)
        
        #Fill Background
        non_empty = pdb.gimp_edit_copy(leatherLayer)
        pdb.gimp_image_remove_layer(img, leatherLayer)
        drawable = pdb.gimp_image_get_layer_by_name(img, "Background")
        pdb.gimp_item_set_visible(drawable, TRUE)
        pdb.gimp_item_set_name(drawable, "Leather")
        pdb.gimp_context_set_pattern("Clipboard Image")
        pdb.gimp_edit_bucket_fill(drawable, BUCKET_FILL_PATTERN, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
        
        #Creating the dark spots on the leather
        spots = pdb.gimp_layer_new_from_drawable(backLayer, img)
        pdb.gimp_image_insert_layer(img, spots, None, 1)
        pdb.gimp_drawable_fill(spots, FILL_WHITE)
        pdb.gimp_layer_set_mode(spots, LAYER_MODE_GRAIN_EXTRACT)
        pdb.gimp_layer_set_opacity(spots, 35)
        pdb.gimp_item_set_name(spots, "Spots")
        pdb.plug_in_solid_noise(img, spots, TRUE, FALSE, 2, 15, 16, 16)
        pdb.plug_in_gauss(img, spots, 150, 150, 1)   #method=1
       
        #Creating the wrinkles on the leather
        wrinklesLayer = pdb.gimp_layer_new_from_drawable(spots, img)
        pdb.gimp_image_insert_layer(img, wrinklesLayer, None, 1)
        pdb.gimp_layer_set_mode(wrinklesLayer, LAYER_MODE_SOFTLIGHT)
        pdb.gimp_layer_set_opacity(wrinklesLayer, 50)
        pdb.plug_in_gmic_qt(img, wrinklesLayer, 1, 0, "-fx_cracks 14,1,255,255,255,128,0,0,50,50")
        pdb.plug_in_gmic_qt(img, wrinklesLayer, 1, 0, "-fx_breaks 0,42,27,0.3,3")
        pdb.plug_in_gauss(img, wrinklesLayer, 3, 3, 1)   #method=1
        backLayer = pdb.gimp_image_merge_visible_layers(img, EXPAND_AS_NECESSARY)   
        
        pdb.gimp_item_set_visible(textLayer, TRUE)
        pdb.gimp_layer_set_opacity(textLayer, 60)
        pdb.gimp_image_select_item(img, 2, textLayer)
        pdb.gimp_selection_feather(img, 3)
        pdb.gimp_selection_invert(img)
        pdb.script_fu_drop_shadow(img, textLayer, 3, 3, 1, "#000000", 100, FALSE)
        pdb.gimp_selection_invert(img)
        pdb.script_fu_drop_shadow(img, textLayer, 3, 3, 1, "#ffffff", 100, FALSE)
        dropshaLayer = pdb.gimp_image_get_layer_by_name(img, "Drop Shadow #1")
        pdb.gimp_layer_set_mode(dropshaLayer, LAYER_MODE_SOFTLIGHT_LEGACY)
        pdb.gimp_layer_set_opacity(dropshaLayer, 50)
        pdb.gimp_selection_none(img)

    #Image process
    pdb.gimp_displays_flush()
    
    #Resets the previous user defaults
    pdb.gimp_context_pop()     
        
register(
    "pm_create_leather_text_atl",
    "Creates a leather text",
    "Creates a leather texture and text",
    "Pocholo",
    "Pocholo",
    "2022",
    "Leather Text atl",
    "",
    [
    (PF_IMAGE,    "img", "Input image", None),    #current image
    (PF_DRAWABLE, "drawable", "Input layer", None), #current layer   
    (PF_COLOR, "color1", "Leather Main Color", (152, 120, 82)),
    (PF_COLOR, "color2", "Shade Color", (98, 74, 46)),
    (PF_OPTION,  "emboss_deboss", "Text Effect:", 0 ,[" ", "Emboss", "Press"]),
    ],
    [],
    pm_create_leather_text_atl, menu="<Image>/Filters/Alpha to Logo"),

       
register(
    "pm_create_leather_text",
    "Creates a leather text",
    "Creates a leather texture and text",
    "Pocholo",
    "Pocholo",
    "2022",
    "Leather Text",
    "",
    [
    (PF_TEXT, "customtext", "Text string", "LEATHER"),
    (PF_FONT, "fontname", "Font name", "Square Wood-7"),
    (PF_COLOR, "color1", "Leather Main Color", (152, 120, 82)),
    (PF_COLOR, "color2", "Shade Color", (98, 74, 46)),
    (PF_OPTION,  "emboss_deboss", "Text Effect:", 0 ,[" ", "Emboss", "Press"]),
    ],
    [],
    pm_create_leather_text, menu="<Image>/Python-Fu",
    domain=("gimp20", gimp.locale_directory))
main()	